@@ -19,10 +19,10 @@ class CaseImportChecker(BaseChecker):
     priority = -1
     msgs = {
         'C4003': ('pyspark.sql.functions module should be imported as F instead of f',
-                  'lower-function-case-import',
+                  'lower-case-function-import',
                   'Follow AstrumU convention by importing the functions module using capital F.'),
         'C4004': ('pyspark.sql.types module should be imported as T instead of t',
-                  'lower-type-case-import',
+                  'lower-case-type-import',
                   'Follow AstrumU convention by importing the types module using capital T.'),
     }
     options = ()
@@ -34,11 +34,11 @@ class CaseImportChecker(BaseChecker):
     def _check_import(self, node: nodes.Import):
         if node.names[0][0] == "pyspark.sql.function" and node.names[0][1] == 'f':
             self.add_message(
-                "lower-function-case", node=node
+                "lower-case-function-import", node=node
             )
         if node.names[0][0] == "pyspark.sql.types" and node.names[0][1] == 't':
             self.add_message(
-                "lower-type-case", node=node
+                "lower-case-type-import", node=node
             )
 
     def visit_import(self, node):
